summaryrefslogtreecommitdiff
path: root/addons/web/doc/module/static/src/css
diff options
context:
space:
mode:
authorOlivier Dony <odo@openerp.com>2012-08-21 15:02:02 +0200
committerOlivier Dony <odo@openerp.com>2012-08-21 15:02:02 +0200
commiteec2708f48b4e4c90f7f30dc7131a5aeb44bc4fc (patch)
tree8d11335701b7a6b747938d6bc7f25f94a739cfd0 /addons/web/doc/module/static/src/css
parent29e49980751fd9c607e22c730b0922cdc9a20a9e (diff)
[FIX] OPW 577963: ir_attachment: speed up ir.attachment search for large databases
Frequents calls to list.remove() were being a bottleneck for large document lists (100k+). Using a set make remove() calls much faster. Also turned a read() into a pure SQL command, as its high-level features were unnecessary (security checks performed before and after it anyways) and it was 50% slower than the direct SQL version. This commit has a corresponding addons patch in order to use a set instead of a list in the document module as well. bzr revid: odo@openerp.com-20120821130202-71z83drt347lf45n
Diffstat (limited to 'addons/web/doc/module/static/src/css')
0 files changed, 0 insertions, 0 deletions